@@ -1,12 +1,12 @@
 import t from 'tap'
-import LRU from '../'
+import { LRUCache as LRU } from '../'
 
 const c = new LRU<number, number>({ max: 5 })
 for (let i = 0; i < 9; i++) {
   c.set(i, i)
 }
 
-const d = new LRU(c as unknown as LRU.Options<number, number>)
+const d = new LRU(c)
 d.load(c.dump())
 
 t.strictSame(d, c)
