@@ -1,12 +1,16 @@
 import t from 'tap'
-import LRU from '../'
+import { LRUCache as LRU } from '../'
 
-const checkSize = (c:LRU<any,any>) => {
-  const sizes = (c as unknown as { sizes: number[] }).sizes
-  const {calculatedSize, maxSize} = c
+import { expose } from './fixtures/expose'
+
+const checkSize = (c: LRU<any, any>) => {
+  const e = expose(c)
+  const sizes = e.sizes
+  if (!sizes) throw new Error('no sizes??')
+  const { calculatedSize, maxSize } = c
   const sum = [...sizes].reduce((a, b) => a + b, 0)
   if (sum !== calculatedSize) {
-    console.error({sum, calculatedSize, sizes})
+    console.error({ sum, calculatedSize, sizes }, c, e)
     throw new Error('calculatedSize does not equal sum of sizes')
   }
   if (calculatedSize > maxSize) {
@@ -153,18 +157,25 @@ t.test('delete while empty, or missing key, is no-op', t => {
 })
 
 t.test('large item falls out of cache, sizes are kept correct', t => {
+  const statuses: LRU.Status<number>[] = []
+  const s = (): LRU.Status<number> => {
+    const status: LRU.Status<number> = {}
+    statuses.push(status)
+    return status
+  }
+
   const c = new LRU<number, number>({
     maxSize: 10,
     sizeCalculation: () => 100,
   })
-  const sizes:number[] = (c as unknown as { sizes: number[] }).sizes
+  const sizes = expose(c).sizes
 
   checkSize(c)
   t.equal(c.size, 0)
   t.equal(c.calculatedSize, 0)
   t.same(sizes, [])
 
-  c.set(2, 2, { size: 2 })
+  c.set(2, 2, { size: 2, status: s() })
   checkSize(c)
   t.equal(c.size, 1)
   t.equal(c.calculatedSize, 2)
@@ -176,41 +187,49 @@ t.test('large item falls out of cache, sizes are kept correct', t => {
   t.equal(c.calculatedSize, 0)
   t.same(sizes, [0])
 
-  c.set(1, 1)
+  c.set(1, 1, { status: s() })
   checkSize(c)
   t.equal(c.size, 0)
   t.equal(c.calculatedSize, 0)
   t.same(sizes, [0])
 
-  c.set(3, 3, { size: 3 })
+  c.set(3, 3, { size: 3, status: s() })
   checkSize(c)
   t.equal(c.size, 1)
   t.equal(c.calculatedSize, 3)
   t.same(sizes, [3])
 
-  c.set(4, 4)
+  c.set(4, 4, { status: s() })
   checkSize(c)
   t.equal(c.size, 1)
   t.equal(c.calculatedSize, 3)
   t.same(sizes, [3])
 
+  t.matchSnapshot(statuses, 'status updates')
   t.end()
 })
 
 t.test('large item falls out of cache because maxEntrySize', t => {
+  const statuses: LRU.Status<number>[] = []
+  const s = (): LRU.Status<number> => {
+    const status: LRU.Status<number> = {}
+    statuses.push(status)
+    return status
+  }
+
   const c = new LRU<number, number>({
     maxSize: 1000,
     maxEntrySize: 10,
     sizeCalculation: () => 100,
   })
-  const sizes:number[] = (c as unknown as { sizes: number[] }).sizes
+  const sizes = expose(c).sizes
 
   checkSize(c)
   t.equal(c.size, 0)
   t.equal(c.calculatedSize, 0)
   t.same(sizes, [])
 
-  c.set(2, 2, { size: 2 })
+  c.set(2, 2, { size: 2, status: s() })
   checkSize(c)
   t.equal(c.size, 1)
   t.equal(c.calculatedSize, 2)
@@ -222,24 +241,25 @@ t.test('large item falls out of cache because maxEntrySize', t => {
   t.equal(c.calculatedSize, 0)
   t.same(sizes, [0])
 
-  c.set(1, 1)
+  c.set(1, 1, { status: s() })
   checkSize(c)
   t.equal(c.size, 0)
   t.equal(c.calculatedSize, 0)
   t.same(sizes, [0])
 
-  c.set(3, 3, { size: 3 })
+  c.set(3, 3, { size: 3, status: s() })
   checkSize(c)
   t.equal(c.size, 1)
   t.equal(c.calculatedSize, 3)
   t.same(sizes, [3])
 
-  c.set(4, 4)
+  c.set(4, 4, { status: s() })
   checkSize(c)
   t.equal(c.size, 1)
   t.equal(c.calculatedSize, 3)
   t.same(sizes, [3])
 
+  t.matchSnapshot(statuses, 'status updates')
   t.end()
 })
 
